%global __spec_install_pre %{___build_pre}

Summary: The Linux RT kernel

# realtime kernels are named "kernel-rt"
%define kernel kernel
%define realtime rt

# mrgN
%define iteration 79

# The preempt RT patch level
%define rtrev 31
%define rttag rt%{rtrev}

# What parts do we want to build?  We must build at least one kernel.
# These are the kernels that are built IF the architecture allows it.

%define buildrt 1
%define builddoc 1
%define builddebug 1
%define buildheaders 0
%define buildvanilla 1
%define buildtrace 1
%define buildvirt 0
%define buildperf 1
%define buildfirmware 1

# enable or disable debuginfo package creation
%define with_debuginfo 1

# use dracut or mkinitrd?
%define with_dracut 1

# lazy compatibility layer
%define with_up %{buildrt}
%define with_debug %{builddebug}
%define with_trace %{buildtrace}
%define with_virt %{buildvirt}
%define with_perf %{buildperf}
%define with_perftool %{buildperf}
%define with_firmware %{buildfirmware}
%define with_headers %{buildheaders}
%define with_doc %{builddoc}

# For a stable, released kernel, released_kernel should be 1. For rawhide
# and/or a kernel built from an rc or git snapshot, released_kernel should
# be 0.
%define released_kernel 1

# Versions of various parts

# Polite request for people who spin their own kernel rpms:
# please modify the "buildid" define in a way that identifies
# that the kernel isn't the stock distribution kernel, for example,
# by setting the define to ".local" or ".bz123456"
#
# % define buildid .local

%define rhel 1
%if %{rhel}
%define distro_build  0
### %define signmodules 1
%define signmodules 0
%else
# fedora_build defines which build revision of this kernel version we're
# building. Rather than incrementing forever, as with the prior versioning
# setup, we set fedora_cvs_origin to the current cvs revision s/1.// of the
# kernel spec when the kernel is rebased, so fedora_build automatically
# works out to the offset from the rebase, so it doesn't get too ginormous.
#
# If you're building on a branch, the RCS revision will be something like
# 1.1205.1.1.  In this case we drop the initial 1, subtract fedora_cvs_origin
# from the second number, and then append the rest of the RCS string as is.
# Don't stare at the awk too long, you'll go blind.
%define fedora_cvs_origin   1462
%define fedora_cvs_revision() %2
%global distro_build %(echo %{fedora_cvs_origin}.%{fedora_cvs_revision $Revision: 1.644 $} | awk -F . '{ OFS = "."; ORS = ""; print $3 - $1 ; i = 4 ; OFS = ""; while (i <= NF) { print ".", $i ; i++} }')
%define distro_build %{fedora_build}
%define signmodules 0
%endif

# if patch fuzzy patch applying will be forbidden
%define with_fuzzy_patches 0

# base_sublevel is the kernel version we're starting with and patching
# on top of -- for example, 2.6.22-rc7-git1 starts with a 2.6.21 base,
# which yields a base_sublevel of 21.
%define base_sublevel 33

## If this is a released kernel ##
%if 0%{?released_kernel}

# Do we have a -stable update to apply?
%define stable_update 9
# Fix a misnaming in later RT patches
%define stable_minor_rev 0
%if 0%{?stable_minor_rev}
%define stable_minor .%{stable_minor_rev}
%endif

# Is it a -stable RC?
%define stable_rc 0
# Set rpm version accordingly
%if 0%{?stable_update}
%define stablerev .%{stable_update}
%define stable_base %{stable_update}
%if 0%{?stable_rc}
# stable RCs are incremental patches, so we need the previous stable patch
%define stable_base %(echo $((%{stable_update} - 1)))
%endif
%endif
%define rpmversion 2.6.%{base_sublevel}%{?stablerev}%{?stable_minor}

## The not-released-kernel case ##
%else
# The next upstream release sublevel (base_sublevel+1)
%define upstream_sublevel %(echo $((%{base_sublevel} + 1)))
# The rc snapshot level
%define rcrev 0
# The git snapshot level
%define gitrev 0
# Set rpm version accordingly
%define rpmversion 2.6.%{upstream_sublevel}
%endif
# Nb: The above rcrev and gitrev values automagically define Patch00 and Patch01 below.

# What parts do we want to build?  We must build at least one kernel.
# These are the kernels that are built IF the architecture allows it.
# All should default to 1 (enabled) and be flipped to 0 (disabled)
# by later arch-specific checks.

# The following build options are enabled by default.
# Use either --without <opt> in your rpmbuild command or force values
# to 0 in here to disable them.
#
# perf noarch subpkg
%define with_vdso_install 1

# Build the kernel-doc package, but don't fail the build if it botches.
# Here "true" means "continue" and "false" means "fail the build".
%if 0%{?released_kernel}
%define doc_build_fail false
%else
%define doc_build_fail true
%endif

# Additional options for user-friendly one-off kernel building:
# Only build the base kernel (--with baseonly):
%define with_baseonly  0
# Only build the debug kernel (--with dbgonly):
%define with_dbgonly   0

# should we do C=1 builds with sparse
%define with_sparse	%{?_with_sparse:      1} %{?!_with_sparse:      0}

# pkg_release is what we'll fill in for the rpm Release: field
%if 0%{?released_kernel}

%if 0%{?stable_rc}
%define stable_rctag .rc%{stable_rc}
%endif
### Old naming convention w/o rtX
### %define pkg_release %{distro_build}%{?stable_rctag}%{?dist}%{?buildid}
### %define pkg_release %{rttag}.%{iteration}%{distro_build}%{?stable_rctag}%{?dist}%{?buildid}
%define pkg_release %{rttag}.%{iteration}{?stable_rctag}.el6rt

%else

# non-released_kernel
%if 0%{?rcrev}
%define rctag .rc%rcrev
%else
%define rctag .rc0
%endif
%if 0%{?gitrev}
%define gittag .git%gitrev
%else
%define gittag .git0
%endif
### Old naming convention w/o rtX
### %define pkg_release 0.%{distro_build}%{?rctag}%{?gittag}%{?dist}%{?buildid}
### %define pkg_release %{rttag}.%{iteration}.0.%{distro_build}%{?rctag}%{?gittag}%{?dist}%{?buildid}
%define pkg_release %{rttag}.%{iteration}.0.%{?rctag}%{?gittag}.el6rt
%endif

# The kernel tarball/base version
%define kversion 2.6.%{base_sublevel}

%define make_target bzImage

%define hdrarch %_target_cpu
%define asmarch %_target_cpu

%define using_upstream_branch 0
%if 0%{?upstream_branch:1}
%define stable_update 0
%define using_upstream_branch 1
%define variant -%{upstream_branch}%{?variant_fedora}
### %define pkg_release %{rttag}.%{iteration}.0.%{distro_build}%{upstream_branch_tag}%{?dist}%{?buildid}
%define pkg_release %{rttag}.%{iteration}.0.%{upstream_branch_tag}.el6rt
%endif

%if %{rhel}
### %define pkg_release %{rttag}.%{iteration}.%{distro_build}%{?dist}%{?buildid}
%define pkg_release %{rttag}.%{iteration}.el6rt
%endif
%define KVERREL %{rpmversion}-%{pkg_release}.%{_target_cpu}

%if !%{with_debuginfo}
%define _enable_debug_packages 0
%define fancy_debuginfo 0
%else
%define _enable_debug_packages 1
%define fancy_debuginfo 1
%endif
%define debuginfodir /usr/lib/debug

# if requested, only build base kernel
%if %{with_baseonly}
%define with_debug 0
%endif

# if requested, only build debug kernel
%if %{with_dbgonly}
%if %{debugbuildsenabled}
%define with_up 0
%endif
%define with_perftool 0
%endif

%define all_x86 i386 i686

%if %{with_vdso_install}
# These arches install vdso/ directories.
%define vdso_arches %{all_x86} x86_64 
%endif


# don't do debug builds on anything but i686 and x86_64
%ifnarch i686 x86_64
%define with_debug 0
%endif

# only package docs noarch
%ifnarch noarch
%define with_doc 0
%define with_firmware 0
%endif

# don't build noarch kernels or headers (duh)
%ifarch noarch
%define with_up 0
%define with_headers 0
%define with_perf 0
%define all_arch_configs kernel-%{version}-rt*.config
%endif

# Per-arch tweaks

%define asmarch x86
%define image_install_path boot
%define kernel_image arch/x86/boot/bzImage

%ifarch %{all_x86}
%define hdrarch i386
%define all_arch_configs kernel-%{rpmversion}-i?86-rt*.config
%endif

%ifarch x86_64
%define all_arch_configs kernel-%{rpmversion}-x86_64-rt*.config
%endif

%define oldconfig_target nonint_oldconfig

# To temporarily exclude an architecture from being built, add it to
# %nobuildarches. Do _NOT_ use the ExclusiveArch: line, because if we
# don't build kernel-headers then the new build system will no longer let
# us use the previous build of that package -- it'll just be completely AWOL.
# Which is a BadThing(tm).

# We don't build a kernel on i386; we only do kernel-headers there,
# and we no longer build for 31bit S390. Same for 32bit sparc and arm.
%define nobuildarches i386 i586 i686 s390 sparc sparc64 ppc ia64 %{arm} noarch

%ifarch %nobuildarches
%define with_up 0
%define buildrt 0
%define builddebug 0
%define buildvanilla 0
%define buildtrace 0
%define buildvirt 0
%define with_debuginfo 0
%define with_perftool 0
%define _enable_debug_packages 0
%endif

#
# Three sets of minimum package version requirements in the form of Conflicts:
# to versions below the minimum
#

#
# First the general kernel 2.6 required versions as per
# Documentation/Changes
#
%define kernel_dot_org_conflicts  ppp < 2.4.3-3, isdn4k-utils < 3.2-32, nfs-utils < 1.0.7-12, e2fsprogs < 1.37-4, util-linux < 2.12, jfsutils < 1.1.7-2, reiserfs-utils < 3.6.19-2, xfsprogs < 2.6.13-4, procps < 3.2.5-6.3, oprofile < 0.9.1-2

#
# Then a series of requirements that are distribution specific, either
# because we add patches for something, or the older versions have
# problems with the newer kernel or lack certain things that make
# integration in the distro harder than needed.
#
%define package_conflicts initscripts < 7.23, udev < 145-11, iptables < 1.3.2-1, ipw2200-firmware < 2.4, iwl4965-firmware < 228.57.2, selinux-policy-targeted < 1.25.3-14, squashfs-tools < 4.0, wireless-tools < 29-3

# We moved the drm include files into kernel-headers, make sure there's
# a recent enough libdrm-devel on the system that doesn't have those.
%define kernel_headers_conflicts libdrm-devel < 2.4.0-0.15

#
# Packages that need to be installed before the kernel is, because the %post
# scripts use them.
#
%define kernel_prereq  fileutils, module-init-tools, initscripts >= 8.11.1-1, kernel-rt-firmware >= %{rpmversion}-%{pkg_release}, grubby >= 7.0.4-1, rt-setup
%if %{with_dracut}
%define initrd_prereq  dracut-kernel >= 002-18.git413bcf78
%else
%define initrd_prereq  mkinitrd >= 6.0.61-1
%endif

#
# This macro does requires, provides, conflicts, obsoletes for a kernel package.
#	%%kernel_reqprovconf <subpackage>
# It uses any kernel_<subpackage>_conflicts and kernel_<subpackage>_obsoletes
# macros defined above.
#
%define kernel_reqprovconf \
Provides: kernel = %{rpmversion}-%{pkg_release}\
Provides: kernel-%{_target_cpu} = %{rpmversion}-%{pkg_release}%{?1:.%{1}}\
Provides: kernel-drm = 4.3.0\
Provides: kernel-drm-nouveau = 16\
Provides: kernel-modeset = 1\
Provides: kernel-uname-r = %{KVERREL}%{?1:.%{1}}\
Requires(pre): %{kernel_prereq}\
Requires(pre): %{initrd_prereq}\
Requires(post): /sbin/new-kernel-pkg\
Requires(preun): /sbin/new-kernel-pkg\
Conflicts: %{kernel_dot_org_conflicts}\
Conflicts: %{package_conflicts}\
%{expand:%%{?kernel%{?1:_%{1}}_conflicts:Conflicts: %%{kernel%{?1:_%{1}}_conflicts}}}\
%{expand:%%{?kernel%{?1:_%{1}}_obsoletes:Obsoletes: %%{kernel%{?1:_%{1}}_obsoletes}}}\
%{expand:%%{?kernel%{?1:_%{1}}_provides:Provides: %%{kernel%{?1:_%{1}}_provides}}}\
# We can't let RPM do the dependencies automatic because it'll then pick up\
# a correct but undesirable perl dependency from the module headers which\
# isn't required for the kernel proper to function\
AutoReq: no\
AutoProv: yes\
%{nil}

Name: %{kernel}-%{realtime}
Group: System Environment/Kernel
License: GPLv2
URL: http://www.kernel.org/
Version: %{rpmversion}
Release: %{pkg_release}
# DO NOT CHANGE THE 'ExclusiveArch' LINE TO TEMPORARILY EXCLUDE AN ARCHITECTURE BUILD.
# SET %%nobuildarches (ABOVE) INSTEAD
ExclusiveArch: noarch %{all_x86} x86_64
ExclusiveOS: Linux
Provides: kernel-rt = %{rpmversion}
Provides: kernel-rt-drm = 4.3.0
Provides: kernel-rt-%{_target_cpu} = %{rpmversion}-%{pkg_release}

%kernel_reqprovconf
%ifarch x86_64
Obsoletes: kernel-smp
%endif

#
# List the packages used during the kernel build
#
BuildRequires: module-init-tools, patch >= 2.5.4, bash >= 2.03, sh-utils, tar
BuildRequires: bzip2, findutils, gzip, m4, perl, make >= 3.78, diffutils, gawk
BuildRequires: gcc >= 3.4.2, binutils >= 2.12, redhat-rpm-config
BuildRequires: net-tools, patchutils, rpm-build >= 4.8.0-7
%if %{with_doc}
BuildRequires: xmlto
BuildRequires: asciidoc
%endif
%if %{with_sparse}
BuildRequires: sparse >= 0.4.1
%endif
%if %{buildrt}
%if %{with_perftool}
BuildRequires: elfutils-libelf-devel zlib-devel binutils-devel elfutils-devel asciidoc xmlto
%endif
%endif
%if %{signmodules}
BuildRequires: gnupg
%endif
BuildRequires: python

BuildConflicts: rhbuildsys(DiskFree) < 7Gb

%if %{fancy_debuginfo}
# Fancy new debuginfo generation introduced in Fedora 8.
%define debuginfo_args --strict-build-id
%endif

Source0: %{name}-%{rpmversion}-%{pkg_release}.tar.bz2

Source11: genkey
Source12: perf
Source13: perf-archive
Source14: find-provides
Source15: merge.pl
Source17: sanity_check.py
Source19: extrakeys.pub

Source20: Makefile.config

Source50: kernel-rt-x86_64.config
Source51: kernel-rt-trace-x86_64.config
Source52: kernel-rt-debug-x86_64.config
Source53: kernel-rt-virt-x86_64.config
Source54: kernel-rt-vanilla-x86_64.config

### 2.6.33.9-rt31-mrg63.el6rt
### Started using a unified SRPM


# empty final patch file to facilitate testing of kernel patches
Patch999999: linux-kernel-test.patch

BuildRoot: %{_tmppath}/kernel-%{KVERREL}-root

# Override find_provides to use a script that provides "kernel(symbol) = hash".
# Pass path of the RPM temp dir containing kabideps to find-provides script.
# %global _use_internal_dependency_generator 0
# %define __find_provides %_sourcedir/find-provides %{_tmppath}
# %define __find_requires /usr/lib/rpm/redhat/find-requires kernel

%description
The kernel package contains the Linux kernel (vmlinuz), the core of any
Linux operating system.  The kernel handles the basic functions
of the operating system: memory allocation, process allocation, device
input and output, etc.


%package doc
Summary: Various documentation bits found in the kernel source
Group: Documentation
%description doc
This package contains documentation files from the kernel
source. Various bits of information about the Linux kernel and the
device drivers shipped with it are documented in these files.

You'll want to install this package if you need a reference to the
options that can be passed to Linux kernel modules at load time.


%package headers
Summary: Header files for the Linux kernel for use by glibc
Group: Development/System
Obsoletes: glibc-kernheaders
Provides: glibc-kernheaders = 3.0-46
%description headers
Kernel-headers includes the C header files that specify the interface
between the Linux kernel and userspace libraries and programs.  The
header files define structures and constants that are needed for
building most standard programs and are also needed for rebuilding the
glibc package.

%package firmware
Summary: Firmware files used by the Linux kernel
Group: Development/System
# This is... complicated.
# Look at the WHENCE file.
License: GPL+ and GPLv2+ and MIT and Redistributable, no modification permitted
Provides: kernel-firmware = %{rpmversion}-%{pkg_release}
Provides: kernel-rt-firmware = %{rpmversion}-%{pkg_release}
%description firmware
Kernel-firmware includes firmware files required for some devices to
operate.

%package debuginfo-common-%{_target_cpu}
Summary: Kernel source files used by %{name}-debuginfo packages
Group: Development/Debug
%description debuginfo-common-%{_target_cpu}
This package is required by %{name}-debuginfo subpackages.
It provides the kernel source files common to all builds.

%if %{buildrt}
%if %{buildperf}
%package -n perf
Summary: Performance monitoring for the Linux kernel
Group: Development/System
Provides: perl(Perf::Trace::Context), perl(Perf::Trace::Core), perl(Perf::Trace::Util)
License: GPLv2
%description -n perf
This package provides the supporting documentation for the perf tool
shipped in each kernel image subpackage.
%endif
%endif

#
# This macro creates a kernel-<subpackage>-debuginfo package.
#	%%kernel_debuginfo_package <subpackage>
#
%define kernel_debuginfo_package() \
%package %{?1:%{1}-}debuginfo\
Summary: Debug information for package %{name}%{?1:-%{1}}\
Group: Development/Debug\
Requires: %{name}-debuginfo-common-%{_target_cpu} = %{version}-%{release}\
Provides: %{name}%{?1:-%{1}}-debuginfo-%{_target_cpu} = %{version}-%{release}\
AutoReqProv: no\
%description -n %{name}%{?1:-%{1}}-debuginfo\
This package provides debug information for package %{name}%{?1:-%{1}}.\
This is required to use SystemTap with %{name}%{?1:-rt%{1}}-%{KVERREL}.\
%{expand:%%global debuginfo_args %{?debuginfo_args} -p '/.*/%%{KVERREL}%{?1:\.%{1}}/.*|/.*%%{KVERREL}%{?1:\.%{1}}(\.debug)?' -o debuginfo%{?1}.list}\
%{nil}

#
# This macro creates a kernel-<subpackage>-devel package.
#	%%kernel_devel_package <subpackage> <pretty-name>
#
%define kernel_devel_package() \
%package %{?1:%{1}-}devel\
Summary: Development package for building kernel modules to match the %{?2:rt%{2} }kernel\
Group: System Environment/Kernel\
Provides: kernel-rt%{?1:-%{1}}-devel-%{_target_cpu} = %{version}-%{release}\
Provides: kernel-rt-devel-%{_target_cpu} = %{version}-%{release}%{?1:.rt%{1}}\
Provides: kernel-rt-devel = %{version}-%{release}%{?1:.rt%{1}}\
Provides: kernel-rt-devel-uname-r = %{KVERREL}%{?1:.rt%{1}}\
AutoReqProv: no\
Requires(pre): /usr/bin/find\
%description -n kernel-rt%{?variant}%{?1:-%{1}}-devel\
This package provides kernel headers and makefiles sufficient to build modules\
against the %{?2:%{2} }kernel package.\
%{nil}

#
# This macro creates a kernel-<subpackage> and its -devel and -debuginfo too.
#	%%define variant_summary The Linux kernel compiled for <configuration>
#	%%kernel_variant_package [-n <pretty-name>] <subpackage>
#
%define kernel_variant_package(n:) \
%package %1\
Summary: %{variant_summary}\
Group: System Environment/Kernel\
%kernel_reqprovconf\
%{expand:%%kernel_devel_package %1 %{!?-n:%1}%{?-n:%{-n*}}}\
%{expand:%%kernel_debuginfo_package %1}\
%{nil}


# First the auxiliary packages of the main kernel package.
%kernel_devel_package
%kernel_debuginfo_package


# Now, each variant package.

# kernel-rt-debug
%define variant_summary The Linux kernel compiled with extra debugging enabled
%kernel_variant_package debug
%description debug
The kernel package contains the Linux kernel (vmlinuz), the core of any
Linux operating system.  The kernel handles the basic functions
of the operating system:  memory allocation, process allocation, device
input and output, etc.

This variant of the kernel has numerous debugging options enabled.
It should only be installed when trying to gather additional information
on kernel bugs, as some of these options impact performance noticably.

# kernel-rt-trace
%define variant_summary The Linux kernel compiled with extra tracing options enabled
%kernel_variant_package trace
%description trace
The kernel package contains the Linux kernel (vmlinuz), the core of any
Linux operating system.  The kernel handles the basic functions
of the operating system:  memory allocation, process allocation, device
input and output, etc.

This variant of the kernel has numerous tracing options enabled.
It should only be installed when trying to gather additional information
on kernel bugs, as some of these options impact performance noticably.

# kernel-rt-virt   EXPERIMENTAL!!! NON-SHIPPING!!!
%define variant_summary The Linux kernel compiled with extra Virtualization options enabled (EXPERIMENTAL)
%kernel_variant_package virt
%description virt
The kernel package contains the Linux kernel (vmlinuz), the core of any
Linux operating system.  The kernel handles the basic functions
of the operating system:  memory allocation, process allocation, device
input and output, etc.

This variant of the kernel has numerous Virtualization options enabled.
Experimental effort, not shipped.

# kernel-rt-vanilla
%define variant_summary The Linux kernel compiled without RT capabilities for debugging
%kernel_variant_package vanilla
%description vanilla
The kernel package contains the Linux kernel (vmlinuz), the core of any
Linux operating system.  The kernel handles the basic functions
of the operating system:  memory allocation, process allocation, device
input and output, etc.

This variant of the kernel has the realtime capabilities disabled, but
has a configuration close to the one used in the realtime kernel.
It should only be installed when trying to gather additional information
on kernel bugs.


%prep
# we don't want a .config file when building firmware: it just confuses the build system
%define build_firmware \
   # mv .config .config.firmware_save \
   make INSTALL_FW_PATH=$RPM_BUILD_ROOT/lib/firmware/%{rpmversion}-%{pkg_release} firmware_install \
   # mv .config.firmware_save .config \
   ln -s /lib/firmware/%{rpmversion}-%{pkg_release} $RPM_BUILD_ROOT/lib/firmware/%{rpmversion}-%{pkg_release}.i686 \
   ln -s /lib/firmware/%{rpmversion}-%{pkg_release} $RPM_BUILD_ROOT/lib/firmware/%{rpmversion}-%{pkg_release}.x86_64 \
   for kvname in rtdebug rttrace rtvirt; do \
      ln -s /lib/firmware/%{rpmversion}-%{pkg_release} $RPM_BUILD_ROOT/lib/firmware/%{rpmversion}-%{pkg_release}.i686.$kvname \
      ln -s /lib/firmware/%{rpmversion}-%{pkg_release} $RPM_BUILD_ROOT/lib/firmware/%{rpmversion}-%{pkg_release}.x86_64.$kvname \
   done

if [ ! -d kernel-%{kversion}/vanilla-%{kversion}/ ]; then
	rm -f pax_global_header;
%setup -q -n kernel-%{kversion} -c
	mv %{name}-%{rpmversion}-%{pkg_release} vanilla-%{kversion};
else
	cd kernel-%{kversion}/;
fi

if [ -d linux-%{kversion}.%{_target_cpu} ]; then
  # Just in case we ctrl-c'd a prep already
  rm -rf deleteme.%{_target_cpu}
  # Move away the stale away, and delete in background.
  mv linux-%{kversion}.%{_target_cpu} deleteme.%{_target_cpu}
  rm -rf deleteme.%{_target_cpu} &
fi

cp -rl vanilla-%{kversion} linux-%{kversion}.%{_target_cpu}

cd linux-%{kversion}.%{_target_cpu}

# Drop some necessary files from the source dir into the buildroot
cp %{SOURCE15} %{SOURCE17} .

# Any further pre-build tree manipulations happen here.

chmod +x scripts/checkpatch.pl

# only deal with configs if we are going to build for the arch
%ifnarch %nobuildarches

mkdir configs

# Change static configuration file names accordingly
cp %{SOURCE50} kernel-%{version}-x86_64-rt.config
cp %{SOURCE51} kernel-%{version}-x86_64-rttrace.config
cp %{SOURCE52} kernel-%{version}-x86_64-rtdebug.config
cp %{SOURCE53} kernel-%{version}-x86_64-rtvirt.config
cp %{SOURCE54} kernel-%{version}-x86_64-rtvanilla.config

# Remove configs not for the buildarch
for cfg in kernel-%{version}-*.config; do
  if [ `echo %{all_arch_configs} | grep -c $cfg` -eq 0 ]; then
    rm -f $cfg
  fi
done

%if !%{with_debug}
rm -f kernel-%{version}-*debug.config
%endif

# now run oldconfig over all the config files
for i in *.config
do
  mv $i .config
  Arch=`head -1 .config | cut -b 3-`
  make ARCH=$Arch %{oldconfig_target} > /dev/null
  echo "# $Arch" > configs/$i
  cat .config >> configs/$i
  rm -f include/generated/kernel.arch
  rm -f include/generated/kernel.cross
done
# end of kernel config
%endif

# get rid of unwanted files resulting from patch fuzz
find . \( -name "*.orig" -o -name "*~" \) -exec rm -f {} \; >/dev/null

%if %{signmodules}
cp %{SOURCE19} .
cat <<EOF
###
### Now generating a PGP key pair to be used for signing modules.
###
### If this takes a long time, you might wish to run rngd in the background to
### keep the supply of entropy topped up.  It needs to be run as root, and
### should use a hardware random number generator if one is available, eg:
###
###     rngd -r /dev/hwrandom
###
### If one isn't available, the pseudo-random number generator can be used:
###
###     rngd -r /dev/urandom
###
EOF
gpg --homedir . --batch --gen-key %{SOURCE11}
cat <<EOF
###
### Key pair generated.
###
EOF
# if there're external keys to be included
if [ -s %{SOURCE19} ]; then
	gpg --homedir . --no-default-keyring --keyring kernel.pub --import %{SOURCE19}
fi
gpg --homedir . --export --keyring ./kernel.pub Red > extract.pub
gcc -o scripts/bin2c scripts/bin2c.c
scripts/bin2c ksign_def_public_key __initdata <extract.pub >crypto/signature/key.h
%endif

cd ..

###
### build
###
%build

%if %{with_sparse}
%define sparse_mflags	C=1
%endif

%if %{fancy_debuginfo}
# This override tweaks the kernel makefiles so that we run debugedit on an
# object before embedding it.  When we later run find-debuginfo.sh, it will
# run debugedit again.  The edits it does change the build ID bits embedded
# in the stripped object, but repeating debugedit is a no-op.  We do it
# beforehand to get the proper final build ID bits into the embedded image.
# This affects the vDSO images in vmlinux, and the vmlinux image in bzImage.
export AFTER_LINK=\
'sh -xc "/usr/lib/rpm/debugedit -b $$RPM_BUILD_DIR -d /usr/src/debug -i $@"'
%endif

cp_vmlinux()
{
  eu-strip --remove-comment -o "$2" "$1"
}

BuildKernel() {
    MakeTarget=$1
    KernelImage=$2
    Flavour=$3
    InstallName=${4:-vmlinuz}

    # Pick the right config file for the kernel we're building
    Config=kernel-%{version}-%{_target_cpu}-rt${Flavour}.config
    DevelDir=/usr/src/kernels/%{KVERREL}${Flavour:+.rt${Flavour}}

    # When the bootable image is just the ELF kernel, strip it.
    # We already copy the unstripped file into the debuginfo package.
    if [ "$KernelImage" = vmlinux ]; then
      CopyKernel=cp_vmlinux
    else
      CopyKernel=cp
    fi

    KernelVer=%{version}-%{release}.%{_target_cpu}${Flavour:+.rt${Flavour}}
    echo BUILDING A KERNEL FOR ${Flavour} %{_target_cpu}...

    # make sure EXTRAVERSION says what we want it to say
    perl -p -i -e "s/^EXTRAVERSION.*/EXTRAVERSION = %{?stablerev}%{?stable_minor}-%{release}.%{_target_cpu}${Flavour:+.rt${Flavour}}/" Makefile

    # if pre-rc1 devel kernel, must fix up SUBLEVEL for our versioning scheme
    %if !0%{?rcrev}
    %if 0%{?gitrev}
    perl -p -i -e 's/^SUBLEVEL.*/SUBLEVEL = %{upstream_sublevel}/' Makefile
    %endif
    %endif

    # and now to start the build process

    make -s mrproper
    cp configs/$Config .config

    Arch=`head -1 .config | cut -b 3-`
    echo USING ARCH=$Arch

    make -s ARCH=$Arch %{oldconfig_target} > /dev/null
    make -s ARCH=$Arch V=1 %{?_smp_mflags} $MakeTarget %{?sparse_mflags}
    make -s ARCH=$Arch V=1 %{?_smp_mflags} modules %{?sparse_mflags} || exit 1

%if %{buildrt}
%if %{with_perftool}
    if [ -z "$Flavour" ]; then
        pushd tools/perf
        chmod +x util/generate-cmdlist.sh util/PERF-VERSION-GEN
        ### make -s %{?_smp_mflags} V=1 DESTDIR=$RPM_BUILD_ROOT prefix=/usr install
        make -s V=1 %{?_smp_mflags} NO_DEMANGLE=1 perf
        mkdir -p $RPM_BUILD_ROOT/usr/libexec/
        install -m 755 perf $RPM_BUILD_ROOT/usr/libexec/perf.%{KVERREL}%{?Flavour:+.rt%{Flavour}}
        popd
    fi
%endif
%endif

    # Start installing the results
%if %{with_debuginfo}
    mkdir -p $RPM_BUILD_ROOT%{debuginfodir}/boot
    mkdir -p $RPM_BUILD_ROOT%{debuginfodir}/%{image_install_path}
    install -m 644 System.map $RPM_BUILD_ROOT/%{debuginfodir}/boot/System.map-$KernelVer
%endif
    mkdir -p $RPM_BUILD_ROOT/%{image_install_path}
    install -m 644 .config $RPM_BUILD_ROOT/boot/config-$KernelVer
    install -m 644 System.map $RPM_BUILD_ROOT/boot/System.map-$KernelVer
%if %{with_dracut}
    # We estimate the size of the initramfs because rpm needs to take this size
    # into consideration when performing disk space calculations. (See bz #530778)
    dd if=/dev/zero of=$RPM_BUILD_ROOT/boot/initramfs-$KernelVer.img bs=1M count=20
%else
    dd if=/dev/zero of=$RPM_BUILD_ROOT/boot/initrd-$KernelVer.img bs=1M count=5
%endif
    if [ -f arch/$Arch/boot/zImage.stub ]; then
      cp arch/$Arch/boot/zImage.stub $RPM_BUILD_ROOT/%{image_install_path}/zImage.stub-$KernelVer || :
    fi
    $CopyKernel $KernelImage \
    		$RPM_BUILD_ROOT/%{image_install_path}/$InstallName-$KernelVer
    chmod 755 $RPM_BUILD_ROOT/%{image_install_path}/$InstallName-$KernelVer

    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer
    # Override $(mod-fw) because we don't want it to install any firmware
    # We'll do that ourselves with 'make firmware_install'
    make -s ARCH=$Arch INSTALL_MOD_PATH=$RPM_BUILD_ROOT modules_install KERNELRELEASE=$KernelVer mod-fw=

      # check if the modules are being signed
%if %{signmodules}
    if [ -z "$(readelf -n $(find fs/ -name \*.ko | head -n 1) | grep module.sig)" ]; then
        echo "ERROR: modules are NOT signed" >&2;
        exit 1;
    fi
%endif

%ifarch %{vdso_arches}
    make -s ARCH=$Arch INSTALL_MOD_PATH=$RPM_BUILD_ROOT vdso_install KERNELRELEASE=$KernelVer
    if [ ! -s ldconfig-kernel.conf ]; then
      echo > ldconfig-kernel.conf "\
# Placeholder file, no vDSO hwcap entries used in this kernel."
    fi
    %{__install} -D -m 444 ldconfig-kernel.conf \
        $RPM_BUILD_ROOT/etc/ld.so.conf.d/kernel-$KernelVer.conf
%endif

    # And save the headers/makefiles etc for building modules against
    #
    # This all looks scary, but the end result is supposed to be:
    # * all arch relevant include/ files
    # * all Makefile/Kconfig files
    # * all script/ files

    rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/source
    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    (cd $RPM_BUILD_ROOT/lib/modules/$KernelVer ; ln -s build source)
    # dirs for additional modules per module-init-tools, kbuild/modules.txt
    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer/extra
    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer/updates
    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer/weak-updates
    # first copy everything
    cp --parents `find  -type f -name "Makefile*" -o -name "Kconfig*"` $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp System.map $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    if [ -s Module.markers ]; then
      cp Module.markers $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    fi

    # then drop all but the needed Makefiles/Kconfig files
    rm -rf $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/Documentation
    rm -rf $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/scripts
    rm -rf $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include
    cp .config $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp -a scripts $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    if [ -d arch/$Arch/scripts ]; then
      cp -a arch/$Arch/scripts $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/arch/%{_arch} || :
    fi
    if [ -f arch/$Arch/*lds ]; then
      cp -a arch/$Arch/*lds $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/arch/%{_arch}/ || :
    fi
    rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/scripts/*.o
    rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/scripts/*/*.o
    if [ -d arch/%{asmarch}/include ]; then
      cp -a --parents arch/%{asmarch}/include $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    fi
    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include
    cd include
    cp -a $(echo * | sed -e 's/^asm$//') $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include
    if [ -L asm ]; then
      asmdir=$(readlink asm)
      cp -a $asmdir $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include/
      pushd $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include
      ln -s $asmdir asm
      popd
    fi
    # Make sure the Makefile and version.h have a matching timestamp so that
    # external modules can be built
    touch -r $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/Makefile $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include/linux/version.h
    touch -r $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/.config $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include/linux/autoconf.h
    # Copy .config to include/config/auto.conf so "make prepare" is unnecessary.
    cp $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/.config $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include/config/auto.conf
    cd ..

    #
    # save the vmlinux file for kernel debugging into the kernel-debuginfo rpm
    #
%if %{with_debuginfo}
    mkdir -p $RPM_BUILD_ROOT%{debuginfodir}/lib/modules/$KernelVer
    cp vmlinux $RPM_BUILD_ROOT%{debuginfodir}/lib/modules/$KernelVer
%endif

    find $RPM_BUILD_ROOT/lib/modules/$KernelVer -name "*.ko" -type f >modnames

    # mark modules executable so that strip-to-file can strip them
    xargs --no-run-if-empty chmod u+x < modnames

    # Generate a list of modules for block and networking.

    fgrep /drivers/ modnames | xargs --no-run-if-empty nm -upA |
    sed -n 's,^.*/\([^/]*\.ko\):  *U \(.*\)$,\1 \2,p' > drivers.undef

    collect_modules_list()
    {
      sed -r -n -e "s/^([^ ]+) \\.?($2)\$/\\1/p" drivers.undef |
      LC_ALL=C sort -u > $RPM_BUILD_ROOT/lib/modules/$KernelVer/modules.$1
    }

    collect_modules_list networking \
    			 'register_netdev|ieee80211_register_hw|usbnet_probe'
    collect_modules_list block \
    			 'ata_scsi_ioctl|scsi_add_host|scsi_add_host_with_dma|blk_init_queue|register_mtd_blktrans|scsi_esp_register|scsi_register_device_handler'
    collect_modules_list drm \
    			 'drm_open|drm_init'
    collect_modules_list modesetting \
    			 'drm_crtc_init'

    # detect missing or incorrect license tags
    rm -f modinfo
    while read i
    do
      echo -n "${i#$RPM_BUILD_ROOT/lib/modules/$KernelVer/} " >> modinfo
      /sbin/modinfo -l $i >> modinfo
    done < modnames

    egrep -v \
    	  'GPL( v2)?$|Dual BSD/GPL$|Dual MPL/GPL$|GPL and additional rights$' \
	  modinfo && exit 1

    rm -f modinfo modnames

    # remove files that will be auto generated by depmod at rpm -i time
    for i in alias alias.bin ccwmap dep dep.bin ieee1394map inputmap isapnpmap ofmap pcimap seriomap symbols symbols.bin usbmap
    do
      rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/modules.$i
    done

    # Move the devel headers out of the root file system
    mkdir -p $RPM_BUILD_ROOT/usr/src/kernels
    mv $RPM_BUILD_ROOT/lib/modules/$KernelVer/build $RPM_BUILD_ROOT/$DevelDir
    ln -sf ../../..$DevelDir $RPM_BUILD_ROOT/lib/modules/$KernelVer/build

    # copy Module.symvers
    cp Module.symvers $RPM_BUILD_ROOT/$DevelDir
}

###
# DO it...
###

# prepare directories
rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT/boot

cd linux-%{kversion}.%{_target_cpu}

%if %{with_debug}
BuildKernel %make_target %kernel_image debug
%endif

%if %{with_trace}
BuildKernel %make_target %kernel_image trace
%endif

%if %{with_virt}
BuildKernel %make_target %kernel_image virt
%endif

%if %{buildvanilla}
BuildKernel %make_target %kernel_image vanilla
%endif

# maybe %if %{buildrt}
%if %{with_up}
BuildKernel %make_target %kernel_image
%endif

%if %{with_doc}
# Make the HTML and man pages.
make -j1 htmldocs mandocs || %{doc_build_fail}

# sometimes non-world-readable files sneak into the kernel source tree
chmod -R a=rX Documentation
find Documentation -type d | xargs chmod u+w
%endif

%if %{buildrt}
%if %{with_perf}
pushd tools/perf
make %{?_smp_mflags} man || %{doc_build_fail}
popd
%endif
%endif

###
### Special hacks for debuginfo subpackages.
###

# This macro is used by %%install, so we must redefine it before that.
%define debug_package %{nil}

%if %{fancy_debuginfo}
%define __debug_install_post \
  /usr/lib/rpm/find-debuginfo.sh %{debuginfo_args} %{_builddir}/%{?buildsubdir}\
%{nil}
%endif

%if %{with_debuginfo}
%ifnarch noarch
%global __debug_package 1
%files -f debugfiles.list debuginfo-common-%{_target_cpu}
%defattr(-,root,root)
%endif
%endif

###
### install
###

%install
# for some reason, on RHEL-5 RPM_BUILD_ROOT doesn't get set
if [ -z "$RPM_BUILD_ROOT" ]; then
	export RPM_BUILD_ROOT="%{buildroot}";
fi

cd linux-%{kversion}.%{_target_cpu}

%if %{with_doc}
docdir=$RPM_BUILD_ROOT%{_datadir}/doc/kernel-doc-%{rpmversion}
man9dir=$RPM_BUILD_ROOT%{_datadir}/man/man9

# copy the source over
mkdir -p $docdir
tar -f - --exclude=man --exclude='.*' -c Documentation | tar xf - -C $docdir

# Install man pages for the kernel API.
mkdir -p $man9dir
find Documentation/DocBook/man -name '*.9.gz' -print0 |
xargs -0 --no-run-if-empty %{__install} -m 444 -t $man9dir $m
ls $man9dir | grep -q '' || > $man9dir/BROKEN
%endif # with_doc

# perf docs
%if %{buildrt}
%if %{with_perf}
mandir=$RPM_BUILD_ROOT%{_datadir}/man
man1dir=$mandir/man1
pushd tools/perf/Documentation
make install-man mandir=$mandir
popd

pushd $man1dir
for d in *.1; do
 gzip $d;
done
popd

# perf shell wrapper
mkdir -p $RPM_BUILD_ROOT/usr/sbin/
cp $RPM_SOURCE_DIR/perf $RPM_BUILD_ROOT/usr/sbin/perf
chmod 0755 $RPM_BUILD_ROOT/usr/sbin/perf
cp $RPM_SOURCE_DIR/perf-archive $RPM_BUILD_ROOT/usr/sbin/perf-archive
chmod 0755 $RPM_BUILD_ROOT/usr/sbin/perf-archive
mkdir -p $RPM_BUILD_ROOT%{_datadir}/doc/perf
%endif # with_perf
%endif

%if %{with_headers}
# Install kernel headers
make ARCH=%{hdrarch} INSTALL_HDR_PATH=$RPM_BUILD_ROOT/usr headers_install

# Do headers_check but don't die if it fails.
make ARCH=%{hdrarch} INSTALL_HDR_PATH=$RPM_BUILD_ROOT/usr headers_check \
     > hdrwarnings.txt || :
if grep -q exist hdrwarnings.txt; then
   sed s:^$RPM_BUILD_ROOT/usr/include/:: hdrwarnings.txt
   # Temporarily cause a build failure if header inconsistencies.
   # exit 1
fi

find $RPM_BUILD_ROOT/usr/include \
     \( -name .install -o -name .check -o \
     	-name ..install.cmd -o -name ..check.cmd \) | xargs rm -f

# glibc provides scsi headers for itself, for now
rm -rf $RPM_BUILD_ROOT/usr/include/scsi
rm -f $RPM_BUILD_ROOT/usr/include/asm*/atomic.h
rm -f $RPM_BUILD_ROOT/usr/include/asm*/io.h
rm -f $RPM_BUILD_ROOT/usr/include/asm*/irq.h
%endif

%if %{with_firmware}
%{build_firmware}
%endif

###
### clean
###

%clean
rm -rf $RPM_BUILD_ROOT

###
### scripts
###

#
# This macro defines a %%post script for a kernel*-devel package.
#	%%kernel_devel_post [<subpackage>]
#
%define kernel_devel_post() \
%{expand:%%post %{?1:%{1}-}devel}\
if [ -f /etc/sysconfig/kernel ]\
then\
    . /etc/sysconfig/kernel || exit $?\
fi\
if [ "$HARDLINK" != "no" -a -x /usr/sbin/hardlink ]\
then\
    (cd /usr/src/kernels/%{KVERREL}%{?1:.%{1}} &&\
     /usr/bin/find . -type f | while read f; do\
       hardlink -c /usr/src/kernels/*.fc*.*/$f $f\
     done)\
fi\
%{nil}

# This macro defines a %%posttrans script for a kernel package.
#	%%kernel_variant_posttrans [<subpackage>]
# More text can follow to go at the end of this variant's %%post.
#
# grubby might be called during installation when a boot loader configuration
# file is not present, so just drop any error messages. See BZ#610813 for
# more details.
%define kernel_variant_posttrans() \
%{expand:%%posttrans %{?1}}\
%{expand:\
NEWKERNARGS=""\
(/sbin/grubby --info=`/sbin/grubby --default-kernel`) 2>/dev/null | grep -q crashkernel\
if [ $? -ne 0 ]\
then\
	NEWKERNARGS="--kernel-args=\"crashkernel=auto\""\
fi\
%if %{with_dracut}\
/sbin/new-kernel-pkg --package kernel%{?1:-rt%{1}} --mkinitrd --dracut --depmod --update %{KVERREL}%{?1:.rt%{1}} $NEWKERNARGS || exit $?\
%else\
/sbin/new-kernel-pkg --package kernel%{?1:-rt%{1}} --mkinitrd --depmod --update %{KVERREL}%{?1:.rt%{1}} $NEWKERNARGS || exit $?\
%endif}\
/sbin/new-kernel-pkg --package kernel%{?1:-rt%{1}} --rpmposttrans %{KVERREL}%{?1:.rt%{1}} || exit $?\
%{nil}

#
# This macro defines a %%post script for a kernel package and its devel package.
#	%%kernel_variant_post [-v <subpackage>] [-r <replace>]
# More text can follow to go at the end of this variant's %%post.
#
%define kernel_variant_post(v:r:) \
%{expand:%%kernel_devel_post %{?-v*}}\
%{expand:%%kernel_variant_posttrans %{?-v*}}\
%{expand:%%post %{?-v*}}\
%{-r:\
if [ `uname -i` == "x86_64" -o `uname -i` == "i386" ] &&\
   [ -f /etc/sysconfig/kernel ]; then\
  /bin/sed -r -i -e 's/^DEFAULTKERNEL=%{-r*}$/DEFAULTKERNEL=kernel%{?-v:-%{-v*}}/' /etc/sysconfig/kernel || exit $?\
fi}\
%{expand:\
/sbin/new-kernel-pkg --package kernel%{?-v:-%{-v*}} --install %{KVERREL}%{?-v:.rt%{-v*}} || exit $?\
}\
%{nil}


# This macro defines a %%posttrans script for a kernel package.
#	%%kernel_variant_posttrans [<subpackage>]
#
# This macro defines a %%preun script for a kernel package.
#	%%kernel_variant_preun <subpackage>
#
%define kernel_variant_preun() \
%{expand:%%preun %{?1}}\
/sbin/new-kernel-pkg --rminitrd --rmmoddep --remove %{KVERREL}%{?1:.rt%{1}} || exit $?\
%{nil}

# kernel-rt %post script
%kernel_variant_preun 
%kernel_variant_post

# kernel-rt-debug %post script
%kernel_variant_preun debug
%kernel_variant_post -v debug

# kernel-rt-trace %post script
%kernel_variant_preun trace
%kernel_variant_post -v trace

# kernel-rt-virt %post script
%kernel_variant_preun virt
%kernel_variant_post -v virt

# kernel-rt-vanilla %post script
%kernel_variant_preun vanilla
%kernel_variant_post -v vanilla


if [ -x /sbin/ldconfig ]
then
    /sbin/ldconfig -X || exit $?
fi

###
### file lists
###

%if %{with_headers}
%files headers
%defattr(-,root,root)
/usr/include/*
%endif

%if %{with_firmware}
%files firmware
%defattr(-,root,root)
/lib/firmware/*
%doc linux-%{kversion}.%{_target_cpu}/firmware/WHENCE
%endif

# only some architecture builds need kernel-doc
%if %{with_doc}
%files doc
%defattr(-,root,root)
%{_datadir}/doc/kernel-doc-%{rpmversion}/Documentation/*
%dir %{_datadir}/doc/kernel-doc-%{rpmversion}/Documentation
%dir %{_datadir}/doc/kernel-doc-%{rpmversion}
%{_datadir}/man/man9/*
%endif

%if %{buildrt}
%if %{with_perf}
%files -n perf
%defattr(-,root,root)
/usr/sbin/perf
/usr/sbin/perf-archive
/usr/libexec/*
%{_datadir}/man/man1/*
%{_datadir}/doc/perf
%endif
%endif

# This is %{image_install_path} on an arch where that includes ELF files,
# or empty otherwise.
%define elf_image_install_path %{?kernel_image_elf:%{image_install_path}}

#
# This macro defines the %%files sections for a kernel package
# and its devel and debuginfo packages.
#	%%kernel_variant_files [-k vmlinux] <condition> <subpackage>
#
%define kernel_variant_files(k:) \
%if %{1}\
%{expand:%%files %{?2}}\
%defattr(-,root,root)\
/%{image_install_path}/%{?-k:%{-k*}}%{!?-k:vmlinuz}-%{KVERREL}%{?2:.rt%{2}}\
/boot/System.map-%{KVERREL}%{?2:.rt%{2}}\
/boot/config-%{KVERREL}%{?2:.rt%{2}}\
%dir /lib/modules/%{KVERREL}%{?2:.rt%{2}}\
/lib/modules/%{KVERREL}%{?2:.rt%{2}}/kernel\
/lib/modules/%{KVERREL}%{?2:.rt%{2}}/extra\
/lib/modules/%{KVERREL}%{?2:.rt%{2}}/build\
/lib/modules/%{KVERREL}%{?2:.rt%{2}}/source\
/lib/modules/%{KVERREL}%{?2:.rt%{2}}/updates\
/lib/modules/%{KVERREL}%{?2:.rt%{2}}/weak-updates\
%ifarch %{vdso_arches}\
/lib/modules/%{KVERREL}%{?2:.rt%{2}}/vdso\
/etc/ld.so.conf.d/kernel-%{KVERREL}%{?2:.rt%{2}}.conf\
%endif\
/lib/modules/%{KVERREL}%{?2:.rt%{2}}/modules.*\
%if %{with_dracut}\
%ghost /boot/initramfs-%{KVERREL}%{?2:.rt%{2}}.img\
%else\
%ghost /boot/initrd-%{KVERREL}%{?2:.rt%{2}}.img\
%endif\
%{expand:%%files %{?2:%{2}-}devel}\
%defattr(-,root,root)\
%dir /usr/src/kernels\
/usr/src/kernels/%{KVERREL}%{?2:.rt%{2}}\
%if %{with_debuginfo}\
%ifnarch noarch\
%if %{with_debuginfo}\
%if %{fancy_debuginfo}\
%{expand:%%files -f debuginfo%{?2}.list %{?2:%{2}-}debuginfo}\
%{debuginfodir}/boot/System.map-%{KVERREL}%{?2:.rt%{2}}\
%else\
%{expand:%%files %{?2:%{2}-}debuginfo}\
%endif\
%endif\
%defattr(-,root,root)\
%if %{with_debuginfo}\
%if !%{fancy_debuginfo}\
%if "%{elf_image_install_path}" != ""\
%{debuginfodir}/%{elf_image_install_path}/*-%{KVERREL}%{?2:.rt%{2}}.debug\
%endif\
%endif\
%{debuginfodir}/lib/modules/%{KVERREL}%{?2:.rt%{2}}\
%{debuginfodir}/usr/src/kernels/%{KVERREL}%{?2:.rt%{2}}\
%{debuginfodir}/boot/System.map-%{KVERREL}%{?2:.rt%{2}}\
%endif\
%endif\
%endif\
%endif\
%{nil}

%kernel_variant_files %{with_up}

%if %{with_debug}
%kernel_variant_files %{with_debug} debug
%endif

%if %{with_trace}
%kernel_variant_files %{with_trace} trace
%endif

%if %{with_virt}
%kernel_variant_files %{with_virt} virt
%endif

%if %{buildvanilla}
%kernel_variant_files %{buildvanilla} vanilla
%endif

%changelog
* Wed Jan 04 2012 Luis Claudio R. Goncalves <lgoncalv@redhat.com> - 2.6.33.9-rt31.mrg79
- Turn off -virt packages for production build

* Mon Dec 19 2011 Luis Claudio R. Goncalves <lgoncalv@redhat.com> - 2.6.33.9-rt31.mrg78
- [pkg] fixed build-id mismatch between kernel and its debuginfo pkg [768413]

* Sun Dec 18 2011 Luis Claudio R. Goncalves <lgoncalv@redhat.com> - 2.6.33.9-rt31.mrg77
- Enabled the pmcraid and pm8001 drivers [753992]
- [net] gro: only reset frag0 when skb can be pulled [761340] {CVE-2011-2723}
- [net] ipv6: udp: fix the wrong headroom check [755589] {CVE-2011-4326}
- [net] b43: allocate receive buffers big enough for max frame len + offset [761368] {CVE-2011-3359}
- [crypto] ghash: null pointer deref if no key is set [749483] {CVE-2011-4081}
- [crypto] keys: fix a NULL pointer deref in the user-defined key type [751302] {CVE-2011-4110}
- [fs] proc: fix oops on invalid /proc/<pid>/maps access [751616] {CVE-2011-3637}
- [tools] perf tools: do not look at ./config for configuration [730205] {CVE-2011-2905}
- [fs] fuse: check size of FUSE_NOTIFY_INVAL_ENTRY message [736766] {CVE-2011-3353}
- [fs] cifs: always do is_path_accessible check in cifs_mount [761369] {CVE-2011-3363}
- [sec] tpm: Zero buffer after copying to userspace [760578] {CVE-2011-1162}
- [process] taskstats io infoleak [761355] {CVE-2011-2494}
- [fs] cifs: signedness issue in CIFSFindNext [761363] {CVE-2011-3191}
- [net] af_packet infoleak [761358] {CVE-2011-2898}
- [fs] jbd/jbd2: invalid value of first log block leads to oops [753345] {CVE-2011-4132}
- [net] improve sequence number generation [761362] {CVE-2011-3188}

* Thu Sep 08 2011 Luis Claudio R. Goncalves <lgoncalv@redhat.com> - 2.6.33.9-rt31.mrg76
- bonding: fix WARN_ON when writing to bond_master sysfs file [738787]
- Added static configurantion files
- Disabled KVM in the production kernel
- Created the kernel-rt-virt package (experimental/non-shipping)

* Tue Aug 23 2011 Luis Claudio R. Goncalves <lgoncalv@redhat.com> - 2.6.33.9-rt31.mrg75
- acpi: /sys/kernel/debug/acpi/custom_method can bypass module restrictions [680844] {CVE-2011-1021}
- add missing cxgb3/t3fw-7.10.0.bin firmware files [728310]
- add /sys/kernel/realtime entry [728551]
- add the crash module [681987]
- agp: insufficient page_count parameter checking in agp_allocate_memory() [699011] {CVE-2011-1746}
- agp: insufficient pg_start parameter checking in AGPIOC_BIND and AGPIOC_UNBIND ioctls [699007] {CVE-2011-1745} {CVE-2011-2022}
- backport: sched/cpupri: Remove the vec->lock [727699]
- backport: timers-avoid-the-base-null-otptimization-on-rt.patch from v3.0.0-rt6 [727549]
- be2net 0000:03:00.0: Error in cmd completion - opcode 103, compl 2, extd 30 [719742]
- bluetooth: buffer overflow in l2cap config request [716811] {CVE-2011-2497}
- bluetooth: l2cap and rfcomm: fix 1 byte infoleak to userspace [703024] {CVE-2011-2492}
- config: disable deprecated CONFIG_NF_CT_ACCT [710158]
- dccp: handle invalid feature options length [703014] {CVE-2011-1770}
- fs: cifs session reuse [697397] {CVE-2011-1585}
- fs: corrupted GUID partition tables can cause kernel oops [695983] {CVE-2011-1577}
- fs: DoS (crash) due slab corruption in inotify_init1 [692096] {CVE-2011-1479}
- fs: ext4: kernel panic when writing data to the last block of sparse file [722564] {CVE-2011-2695}
- fs: no access restrictions of /proc/pid/* after setuid program exec [692040] {CVE-2011-1020}
- fs: /proc/PID/io infoleak  [716831] {CVE-2011-2495}
- fs: /proc/PID/io infoleak [716831] {CVE-2011-2495}
- fs: proc: signedness issue in next_pidmap() [697828] {CVE-2011-1593}
- fs: rpc task leak after flock()ing  NFS share [709550] {CVE-2011-2491}
- fs: validate size of EFI GUID partition entries [703031] {CVE-2011-1776}
- gro: Fix memory leak/corruption on VLAN GRO_DROP [695177] {CVE-2011-1576}
- gro: reset dev and skb_iff on skb reuse [691272] {CVE-2011-1478}
- inet_diag: insufficient validation [714542] {CVE-2011-2213}
- kernel: tpm infoleaks [684676] {CVE-2011-1160}
- kexec: fix Oops in crash_shrink_memory() [730834]
- ksm: race between ksmd and exiting task [710988] {CVE-2011-2183}
- mm: avoid wrapping vm_pgoff in mremap() and stack expansions [716545] {CVE-2011-2496}
- mm: mem allocated invisible to oom_kill() if not attached to threads [625692] {CVE-2010-4243}
- net: missing check in can/bcm socket release [698484] {CVE-2011-1598} {CVE-2011-1748}
- net: netns vs proto registration ordering [702307] {CVE-2011-1767} {CVE-2011-1768}
- net: nl80211: missing check for valid SSID size in scan operations [718156] {CVE-2011-2517}
- nfs4: Ensure that ACL pages sent over NFS were not allocated from the slab [682646] {CVE-2011-1090}
- scsi: mpt2sas: prevent heap overflows [694024] {CVE-2011-1494} {CVE-2011-1495}
- sctp: race between ICMP protocol unreachable and connect() [667030] {CVE-2010-4526}
- taskstats: duplicate entries in listener mode can lead to DoS [715451] {CVE-2011-2484}

* Thu Aug 11 2011 Clark Williams <williams@redhat.com> - 2.6.33.9-rt31.mrg74
- modified specfile to include new dirs and Module.symvers in -devel packages

* Wed Jul 20 2011 Luis Claudio R. Goncalves <lgoncalv@redhat.com> - 2.6.33.9-rt31.mrg73
- bnx2: add missing reference to the a new firmware file in the Makefile

* Mon Jul 11 2011 Luis Claudio R. Goncalves <lgoncalv@redhat.com> - 2.6.33.9-rt31.mrg72
- Added missing files to kernel-rt-devel package (J.H.M. Dassen) [718940]

* Wed Jun 29 2011 Luis Claudio R. Goncalves <lgoncalv@redhat.com> - 2.6.33.9-rt31.mrg71
- tcp: make ato min and delack min tunable [460217] [717261]

* Tue Jun 28 2011 Luis Claudio R. Goncalves <lgoncalv@redhat.com> - 2.6.33.9-rt31.mrg70
- bfa: Use the driver in kernel-2.6.32-163.el6 [712422]
- kdump: implement crashkernel=auto [706961]

* Mon Jun 27 2011 Luis Claudio R. Goncalves <lgoncalv@redhat.com> - 2.6.33.9-rt31.mrg69
- Disable TRACE_BRANCH_PROFILING on kernel-rt-trace because of its overhead
- Disable deprecated CONFIG_NF_CT_ACCT option [710158]
- ftrace: update the docs in Documentation and debugfs [716559]
- ftrace: do not disable interrupts for modules in mcount update [715418]
- sched: Fix need_resched() when checking peempt [717081]
- clocksource: Make watchdog robust vs. interruption [717083]

* Fri Jun 10 2011 Luis Claudio R. Goncalves <lgoncalv@redhat.com> - 2.6.33.9-rt31.mrg68
- Backported the benet (be2net) driver from kernel-2.6.32-154.el6 [707259]
- Updated the following NIC drivers to the version in kernel-2.6.32-154.el6:
- bna, bnx2, bnx2x, chelsio, e100, enic, igb, ixgb, ixgbe, myri10g, netxen, sfc and tg3
- Enabled CHELSIO_T4, QLCNIC and BNA network driver config options

* Mon Jun 06 2011 Luis Claudio R. Goncalves <lgoncalv@redhat.com> - 2.6.33.9-rt31.mrg67
- Relax si_code check in rt_sigqueueinfo and rt_tgsigqueueinfo [711205]

* Wed May 25 2011 Luis Claudio R. Goncalves <lgoncalv@redhat.com> - 2.6.33.9-rt31.mrg66
- Backported PCI _CRS fixes from linux-tip

* Tue May 17 2011 Luis Claudio R. Goncalves <lgoncalv@redhat.com> - 2.6.33.9-rt31.mrg65
- Added bz705582-rhel6-RCUify-posix_timers.patch
- Disabled CONFIG_BOOTPARAM_HUNG_TASK_PANIC in the debug, vanila and trace kernels

* Mon May 09 2011 Luis Claudio R. Goncalves <lgoncalv@redhat.com> - 2.6.33.9-rt31.mrg64
- Re-enabled kernel-rt-vanilla build
- Coupled perf package creation with the production kernel build
- Disabled kernel build for 32bits

* Tue May 03 2011 Luis Claudio R. Goncalves <lgoncalv@redhat.com> - 2.6.33.9-rt31.mrg63
- Created symlinks to the firmware files on all kernel-rt variants
- Disable CONFIG_CAN*
- Disabled kernel-rt-vanilla package
- Synchronized with kernel-rt-2.6.33.9-rt31.63.el5rt
- Added bz695829-watchdog-iTCO_wdt-Cleanup-warning-messages.patch
- Added bz680964-mlx4-make-size-of-mcg-entry-module-param.patch
- Added bz688026_CVE-2011-1163-Fix-corrupted-OSF-partition-table-parsing.patch
- Added bz689326-CVE-2011-1170-netfilter-arp_tables-fix-infoleak.patch
- Added bz689335-CVE-2011-1171-netfilter-ip_tables-fix-infoleak.patch
- Added bz689343-netfilter-ipt_CLUSTERIP-fix-buffer-overflow.patch
- Added bz689345_CVE-2011-1172-ipv6-netfilter-ip6_tables-fix-infoleak.patch
- Added bz677269_CVE-2011-0711-xfs-prevent-leaking-uninitialized-stack-mem.patch
- Added bz692665-bnx2x-Fix-PHY-locking-problem.patch
- Added bz681309-Bluetooth-sco-fix-info-leak-to-userspace.patch
- Added bz681317-Bluetooth-bnep-fix-buffer-overflow.patch
- Added bz681324-segoon-openwall.com.patch
- Added bz679308-video-sn9c102-world-wirtable-sysfs-files.patch
- Added bz679308-scsi-aic94xx-world-writable-sysfs-update_bios-file.patch
- Added bz673145-0001-Author-Jerome-Marchand-jmarchan-redhat.com.patch
- Added bz673145-0002-block-fix-accounting-bug-on-cross-partition-merges.patch
- Added bz673145-0003-block-add-internal-hd-part-table-references.patch

* Mon Apr 25 2011 Luis Claudio R. Goncalves <lgoncalv@redhat.com> - 2.6.33.7.2-rt30-mrg56.4.el6rt
- Added missing firmware files required by newer bnx2 and bnx2x drivers

* Thu Apr 14 2011 Luis Claudio R. Goncalves <lgoncalv@redhat.com> - 2.6.33.7.2-rt30-mrg56.3.el6rt
- Fixed the EXTRAVERSION handling due to the unique kernel name

* Thu Apr 14 2011 Luis Claudio R. Goncalves <lgoncalv@redhat.com> - 2.6.33.7.2-rt30-mrg56.1.el6rt
- Added 0000-rhel6-infrastructure-for-NIC-backports.patch
- Added 0001-bna-Use-the-driver-in-kernel-2.6.32-130.el6.patch
- Added 0002-bnx2-Use-the-driver-in-kernel-2.6.32-130.el6.patch
- Added 0003-bnx2x-Use-the-driver-in-kernel-2.6.32-130.el6.patch
- Added 0004-chelsio-Use-the-drivers-in-kernel-2.6.32-130.el6.patch
- Added 0005-e100-e1000-e1000e-Use-the-driver-in-kernel-2.6.32-13.patch
- Added 0006-enic-Use-the-driver-in-kernel-2.6.32-130.el6.patch
- Added 0007-igb-Use-the-driver-in-kernel-2.6.32-130.el6.patch
- Added 0008-ixgb-Use-the-driver-in-kernel-2.6.32-130.el6.patch
- Added 0009-ixgbe-Use-the-driver-in-kernel-2.6.32-130.el6.patch
- Added 0010-myri10g-Use-the-driver-in-kernel-2.6.32-130.el6.patch
- Added 0011-netxen-Use-the-driver-in-kernel-2.6.32-130.el6.patch
- Added 0012-sfc-Use-the-driver-in-kernel-2.6.32-130.el6.patch
- Added 0013-tg3-Use-the-driver-in-kernel-2.6.32-130.el6.patch
- Added perf-backport-from-2.6.28.patch

* Thu Apr 14 2011 Luis Claudio R. Goncalves <lgoncalv@redhat.com> - 2.6.33.7.2-rt30-mrg56.el6rt
- Synchronized the MRG-2.0 kernel with kernel-rt-2.6.33.7.2-rt30-mrg56
- Incorporated patch-2.6.33.7.2-rt30.bz2
- The following SHA1s refer to commits in v2.6.33.7.2-rt30
- Removed bz625713-Fix-an-Oops-in-the-NFSv4-atomic-open-code.patch
- 	88df8860c784d4d4ba054701c565333fb6317e52
- Removed bz625701-can-add-limit-for-nframes-and-clean-up-signed-unsign.patch
- 	300bc74d197bfbfc7e843b2529e31a93043dfe80
- Removed bz621436-drm-stop-information-leak-of-old-kernel-stack.patch
- Removed bz621436-drm-block-userspace-under-allocating-buffer-and-havi.patch
- The above two patches are equivalent to
-	bf18be070d1b8d87f6ba3c01686e1c8fc3ef0aca
- Removed bz627807-KEYS-Fix-RCU-no-lock-warning-in-keyctl_session_to_pa.patch
-	300f0c0dc280e9ee7a259651d4eb6d3e7ba3488f
- Removed bz627807-KEYS-Fix-bug-in-keyctl_session_to_parent-if-parent-h.patch
-	4d4ea8b53f6dae1fb354b8536a0ead210d6ea6d4
- Removed bz632070-niu-Fix-kernel-buffer-overflow-for-ETHTOOL_GRXCLSRLA.patch
-	1389ed5d809bc8369fa9f9c7f930735397901d6b
- Removed bz631624-tracing-Do-not-allow-llseek-to-set_ftrace_filter.patch
-	dc7dde7adbc57b7461b4b1302c94fe31699f60e2
- Removed bz626316-act_nat-use-stack-variable.patch
-	cd92f998fd8a688dce9b9a7930f6bfbc30d2f918
- Removed bz626316-net-sched-fix-some-kernel-memory-leaks.patch
-	49aa1d9ed423c0d901b5e0c072f1b0269a17a572
- Removed bz628436-wireless-extensions-fix-kernel-heap-content-leak.patch
-	5741fe45da56e3a75eac22942d0fae123ae7d9a0
- Removed bz630553-ALSA-seq-oss-Fix-double-free-at-error-path-of-snd_se.patch
-	85b5abf5021d91c11185e25a542ce1f55b1a0f16
- Removed bz634450-x86-64-compat-Test-rax-for-the-syscall-number-not-ea.patch
-	b2104d5552a93f7efa58be388ad7c3d5faf747ca
- Removed bz634450-x86-64-compat-Retruncate-rax-after-ia32-syscall-entr.patch
-	3609ee783b603f811c3c1d9b2bba3a15dc8030cd
- Removed bz634460-compat-Make-compat_alloc_user_space-incorporate-the.patch
-	c2841fe895b29834edd7137478e2ba19a4a21ef1
- Removed bz607854-mm-make-stack-guard-page-logic-use-vm_prev-pointer.patch
-	3cf7bf56bb62dcb9d99b0060bac4648e2bf8cb16
- Removed bz607854-mm-fix-page-table-unmap-for-stack-guard-page-properl.patch
-	a487cf3a8203643d21d9c14823586e2c72eebaba
- Removed bz607854-mm-fix-missing-page-table-unmap-for-stack-guard-page.patch
-	27ed5f7263e8c301282298ef3d6c911455bba26a
- Removed bz607854-mm-keep-a-guard-page-below-a-grow-down-stack-segment.patch
-	ed313b5159c985cddcc9bc5d3468a7f470c41292
- Removed bz607854-mm-fix-up-some-user-visible-effects-of-the-stack-gua.patch
-	e276f93c1c8ba22adf058e219caaf3fd1e6cecf5
- Removed bz607854-mm-make-the-vma-list-be-doubly-linked.patch
-	498f7001734ff4fb0ef5a494241c1048b1264c0a
- Removed bz607854-mm-make-the-mlock-stack-guard-page-checks-stricter.patch
-	901f364298f4e4a1c3334d291fb90967b25e61de

* Tue Apr 05 2011 Luis Claudio R. Goncalves <lgoncalv@redhat.com> - 2.6.33.7-rt29-mrg55.3.el6rt
- Our firmware file placement is now RHEL6 compatible

* Wed Mar 23 2011 Luis Claudio R. Goncalves <lgoncalv@redhat.com> - 2.6.33.7-rt29-mrg55.2.el6rt
- Added missing kernet_variant_post* macros

* Tue Mar 22 2011 Luis Claudio R. Goncalves <lgoncalv@redhat.com> - 2.6.33.7-rt29-mrg55.1.el6rt
- Reverted the change of firmware files placement

* Tue Mar 15 2011 Luis Claudio R. Goncalves <lgoncalv@redhat.com> - 2.6.33.7-rt29-mrg55.el6rt
- Changed firmware files placement to be compatible with RHEL6 default
- Re-enabled the kernel-rt-vanilla variant for x86_64
- Added ipt_do_tables_lock_hack.patch to fix kernel-rt-vanilla
- Added bz656833_CVE-2010-4250-notify-stop-kernel-mem-leak-on-file-creat.patch
- Added bz636388_CVE-2010-3477-net-sched-fix-kernel-leak-in-act_police.patch
- Added bz652532_CVE-2010-4162-dont-overflow-pg-count-when-mapping-c.patch
- Added bz652960_CVE-2010-4163-CVE-2010-4668-block-chck-length-of-iov-entries-in-blk.patch
- Added bz659574_CVE-2010-4258-do_exit-check-is-run-with-get_fs-USER_DS.patch
- Added bz637043-Avoid-pgoff-overflow-in-remap_file_pages.patch
- Added bz672405_CVE-2011-0521-media-v3-media-av7110-check-for-negative-array-offse.patch
- Added bz672423_CVE-2010-4656-usb-iowarrior-don-t-trust-report_size.patch
- Added bz652509_CVE-2010-4165-tcp-Increase-TCP_MAXSEG-socket-opt-min.patch
- Added bz656763_CVE-2010-4249-lim-total-scm-lower.patch
- Added bz672436_CVE-2010-4655-net-clear-heap-allocations-for-privileged-ethtool.patch
- Added bz668372_CVE-2010-4649-IB-uverbs-Handle-large-num-of-entries-in-poll-CQ.patch
- Added bz667910_CVE-2010-4648-orinoco-fix-TKIP-countermeasure-behaviour.patch
- Added bz662195_CVE-2010-4346-special_mapping-skips-security_file_mmap.patch
- Added bz655661-CVE-2010-4242_bluetooth-Fix-missing-NULL.patch
- Added bz656269-CVE-2010-4248-posix-cpu-timers-workaround.patch
- Added bz663543_CVE-2010-4347-ACPI-debugfs-custom_method-op.patch
- Added bz664559_CVE-2010-4565-CAN-use-inode-instead.patch
- Reenabled bz465837-rtc-compat-rhel5.patch-ported-to-V2.patch

* Wed Feb 02 2011 Luis Claudio R. Goncalves <lgoncalv@redhat.com> - 2.6.33.7-rt29.49.3.el6rt
- First attempt at making perf package from kernel-rt compatible with RHEL6 perf.

* Tue Feb 01 2011 Luis Claudio R. Goncalves <lgoncalv@redhat.com> - 2.6.33.7-rt29.49.2.el6rt
- Re-enabled package kernel-rt-firmware build

* Mon Jan 31 2011 Luis Claudio R. Goncalves <lgoncalv@redhat.com> - 2.6.33.7-rt29.49.1.el6rt
- Fix perf package missing provides

* Thu Jan 26 2011 Luis Claudio R. Goncalves <lgoncalv@redhat.com> - 2.6.33.7-rt29.49.el6rt
- Testing rhel6 template for the RT kernel
- Based on 2.6.33.7-rt29.49 (aka 2.6.33.7.2-rt30.1 MRG)

* Wed Jan 12 2011 John Kacur <jkacur@redhat.com> - 2.6.33.7-rt29-mrg49
- Added bz669187.patch
  The above patch includes the update for v2.6.33.7.2-rt30
  In addition it has two fixes, asm-generic-percpu-fixup-RT-mismerge.patch
  and x86-tsc-Prevent-delayed-init-if-initial-tsc-calibrat.patch

* Tue Dec 21 2010 John Kacur <jkacur@redhat.com> - 2.6.33.7-rt29-mrg48
- Added bz651893-CVE-2010-4160-net-Truncate-recvfrom-and-sendto-length-to-INT_MAX.patch
- Added bz660306-x86-Improve-TSC-calibration-using-a-delayed-workqueu.patch

* Mon Nov 22 2010 Luis Claudio R. Goncalves <lgoncalv@redhat.com> - 2.6.33.7-rt29-mrg47
- Added bz648685-CVE-2010-4072-ipc-shm-fix-information-leak-to-userland.patch
- Added bz648691-CVE-2010-4073-ipc-initialize-structure-memory-to-zero-for-compat-functions.patch
- Added bz648696-CVE-2010-4074-USB-serialmos-prevent-reading-uninitialized-stack-memory.patch
- Added bz648699-CVE-2010-4075-tty-Make-tiocgicount-a-handler.patch
- Added bz648704-CVE-2010-4077-tty-icount-changeover-for-other-main-devices.patch
- Added bz648831-CVE-2010-4079-V4LDVB-ivtvfb-prevent-reading-uninitialized-stack-memory.patch
- Added bz648707-CVE-2010-4080-ALSA-soundpcirme9652-prevent-reading-uninitialized-stack-memory.patch
- Added bz648717-CVE-2010-4082-driversvideoviaioctl.c-prevent-reading-uninitialized-stack-memory.patch
- Added bz648720-CVE-2010-4083-sys_semctl-fix-kernel-stack-leakage.patch
- Added bz651172-CVE-2010-4157-SCSI-gdth-integer-overflow-in-ioctl.patch
- Added bz637689-CVE-2010-2962-drmi915-Sanity-check-preadpwrite.patch
- Added bz642469-CVE-2010-2963-v4l1-fix-32-bit-compat-microcode-loading-translation.patch
- Added bz651674-CVE-2010-4169-perf_events-Fix-perf_counter_mmap-hook-in-mprotect.patch
- Added bz637680-CVE-2010-3432-sctp-Do-not-reset-the-packet-during-sctp_packet_config..patch
- Added bz640460-CVE-2010-3705-sctp-Fix-out-of-bounds-reading-in-sctp_asoc_get_hmac.patch
- Added bz645223-CVE-2010-3858-setup_arg_pages-diagnose-excessive-argument-size.patch
- Added bz646726-CVE-2010-3861-net-clear-heap-allocation-for-ETHTOOL_GRXCLSRLALL.patch
- Added bz651845-CVE-2010-3874-can-bcm-fix-minor-heap-overflow.patch
- Added bz649894-CVE-2010-3876-net-packet-fix-information-leak-to-userland.patch
- Added bz651265-CVE-2010-3880-inet_diag-Make-sure-we-actually-run-the-same-bytecode-we-audited..patch
- Added bz651699-CVE-2010-4158-filter-make-sure-filters-dont-read-uninitialized-memory.patch

* Wed Oct 13 2010 John Kacur <jkacur@redhat.com> - 2.6.33.7-rt29-mrg46
- Added bz638480-ALSA-prevent-heap-corruption-in-snd_ctl_new.patch
- Added bz647434-perf-Mark-software-events-as-irqsafe.patch 
- Modified the kernel-rt.spec file for bz608784

* Wed Oct 6 2010 John Kacur <jkacur@redhat.com> - 2.6.33.7-rt29-mrg45
- Added bz607854-mm-keep-a-guard-page-below-a-grow-down-stack-segment.patch
- Added bz607854-mm-fix-missing-page-table-unmap-for-stack-guard-page.patch
- Added bz607854-x86-don-t-send-SIGBUS-for-kernel-page-faults.patch
- Added bz607854-mm-fix-page-table-unmap-for-stack-guard-page-properl.patch
- Added bz607854-mm-fix-up-some-user-visible-effects-of-the-stack-gua.patch
- Added bz607854-mm-make-the-mlock-stack-guard-page-checks-stricter.patch
- Added bz607854-mm-make-stack-guard-page-logic-use-vm_prev-pointer.patch
- Added bz607854-mm-make-the-vma-list-be-doubly-linked.patch

* Mon Oct 4 2010 Clark Williams <williams@redhat.com> - 2.6.33.7-rt29-mrg44
- removed logic for generating kernel-rt-firmware and requirements for
  that package

* Mon Sep 27 2010 Clark Williams <williams@redhat.com> - 2.6.33.7-rt29-mrg43
- Added manual Provides for perf subpackage

* Sun Sep 26 2010 John Kacur <jkacur@redhat.com> - 2.6.33.7-rt29-mrg42
- Changes to perf

* Tue Sep 21 2010 John Kacur <jkacur@redhat.com> - 2.6.33.7-rt29-mrg41
- CONFIG_HIGHMEM4G=y, and CONFIG_HIGHMEM64G is not set

* Mon Sep 20 2010 John Kacur <jkacur@redhat.com> - 2.6.33.7-rt29-mrg40
- Added bz634460-compat-Make-compat_alloc_user_space-incorporate-the.patch

* Mon Sep 13 2010 John Kacur <jkacur@redhat.com> - 2.6.33.7-rt29-mrg39
- Added bz626316-act_nat-use-stack-variable.patch
- Added bz626316-net-sched-fix-some-kernel-memory-leaks.patch
- Added bz628436-wireless-extensions-fix-kernel-heap-content-leak.patch
- Added bz630553-ALSA-seq-oss-Fix-double-free-at-error-path-of-snd_se.patch
- Added bz634450-x86-64-compat-Test-rax-for-the-syscall-number-not-ea.patch
- Added bz634450-x86-64-compat-Retruncate-rax-after-ia32-syscall-entr.patch
- Added bz629445-aio-check-for-multiplication-overflow-in-do_io_submi.patch
- Added bz633142-drivers-net-usb-hso.c-prevent-reading-uninitialized-.patch
- Added bz633147-drivers-net-eql.c-prevent-reading-uninitialized-stac.patch
- Added bz633151-drivers-net-cxgb3-cxgb3_main.c-prevent-reading-unini.patch

* Thu Sep 9 2010 John Kacur <jkacur@redhat.com> - 2.6.33.7-rt29-mrg38
- Added bz632070-niu-Fix-kernel-buffer-overflow-for-ETHTOOL_GRXCLSRLA.patch
- Added bz631624-tracing-Do-not-allow-llseek-to-set_ftrace_filter.patch
- Reenabled forward-port-of-limit-i386-ram-to-16gb.patch
- Updated and reenabled bz523604-remove-pulse-code-from-the-bnx2x-driver.patch

* Thu Aug 26 2010 John Kacur <jkacur@redhat.com> - 2.6.33.7-rt29-mrg37
- Added bz625713-Fix-an-Oops-in-the-NFSv4-atomic-open-code.patch
- Added bz625701-can-add-limit-for-nframes-and-clean-up-signed-unsign.patch
- Added bz621436-drm-stop-information-leak-of-old-kernel-stack.patch
- Added bz621436-drm-block-userspace-under-allocating-buffer-and-havi.patch
- Added bz627807-KEYS-Fix-RCU-no-lock-warning-in-keyctl_session_to_pa.patch
- Added bz627807-KEYS-Fix-bug-in-keyctl_session_to_parent-if-parent-h.patch
- Turned off CONFIG_LLC

* Tue Aug 17 2010 Luis Claudio R. Goncalves <lgoncalv@redhat.com> - 2.6.33.7-rt29-mrg36
- Removed firmware.patch
- Created the (noarch) kernel-rt-firmware package

* Wed Aug 4 2010 John Kacur <jkacur@redhat.com> - 2.6.33.7-rt29-mrg35
- Rebased to v2.6.33.7-rt29

* Mon Aug 2 2010 John Kacur <jkacur@redhat.com> - 2.6.33.6-rt28-mrg34
- Removed dca-core-cleanup.patch (adds an extra variable, rejected by tglx)
- Turned PAE off
- The following patches can all be removed because they are in -rt28
- Removed consoles-not-working-properly.patch - improved version in -rt28
- Removed 0045-sched-set_cpus_allowed_ptr-Don-t-use-rq-migration_th.patch
- Removed 0046-sched-Kill-the-broken-and-deadlockable-cpuset_lock-c.patch
- Removed 0047-sched-move_task_off_dead_cpu-Take-rq-lock-around-sel.patch
- Removed 0048-sched-move_task_off_dead_cpu-Remove-retry-logic.patch
- Removed 0049-sched-sched_exec-Remove-the-select_fallback_rq-logic.patch
- Removed 0050-sched-_cpu_down-Don-t-play-with-current-cpus_allowed.patch
- Removed 0051-sched-Make-select_fallback_rq-cpuset-friendly.patch
- Removed 0052-0017d735092844118bef006696a750a0e4ef6ebd.patch
- Removed 0053-futex-Protect-against-pi_blocked_on-corruption-durin.patch
- Removed 0054-suspend-Prevent-might-sleep-splats.patch
- Removed 0055-net-iptables-Fix-xt_info-locking.patch
- Removed 0056-x86-mce-Convert-cmci_discover_lock-to-raw_spinlock.patch
- Removed 0057-cpu-hotplug-Don-t-wake-up-the-desched-thread-from-id.patch
- Removed 0058-cpu-hotplug-Prevent-softirq-wakeup-on-wrong-CPU.patch
- Removed 0059-drivers-dca-Convert-dca_lock-to-a-raw-spinlock.patch
- Removed 0060-powerpc-cpu-hotplug-Prevent-softirq-wakeup-on-wrong-.patch
- Removed 0061-dca-Fix-fallout-from-raw_spinlock-conversion.patch

* Thu Jul 29 2010 John Kacur <jkacur@redhat.com> - 2.6.33.6-rt26-mrg33
- Removed convert_dca_lock_to_raw_spinlock_V2.patch (to match git)
- Added dca-core-cleanup.patch (to replace above)

* Thu Jul 28 2010 John Kacur <jkacur@redhat.com> - 2.6.33.6-rt26-mrg32 
- Added consoles-not-working-properly.patch

* Wed Jul 28 2010 John Kacur <jkacur@redhat.com> - 2.6.33.6-rt26-mrg31
- Removed InfiniBand-Add-IBoE-support.patch
- Added bz612275-ibm_rtl-check_DMI_information_in_module_probe.patch
- Removed 0059-drivers-dca-Convert-dca_lock-to-a-raw-spinlock.patch
- Removed 0061-dca-Fix-fallout-from-raw_spinlock-conversion.patch
- Added convert_dca_lock_to_raw_spinlock_V2.patch (Replaces above two)

* Tue Jul 20 2010 Clark Williams <williams@redhat.com> - 2.6.33.6-rt26-mrg30
- merged tip/rt/2.6.33 to pickup:
  - dca_lock fix for igb driver
  - hotplug wakeup fixes
  - TASK_WAKING vs. fork() deadlock fix from peterz
  - various scheduler fixes from oleg
  - PI futex fix from dvhart
  - might_sleep workaround during suspend
  - network fix for xt_info locking

* Sat Jul 17 2010 John Kacur <jkacur@redhat.com> - 2.6.33.6-rt26-mrg29
- Added InfiniBand-Add-IBoE-support.patch

* Wed Jul 14 2010 John Kacur <jkacur@redhat.com> - 2.6.33.6-rt26-mrg28
- Rebasing to 2.6.33.6-rt26
- Removed gianfar-Fix-TX-ring-processing-on-SMP-machines.patch 
- Removed Revert_select_parent_locking_fix.patch
- Removed Make_sure_d_kill_sets_d_parent_to_null.patch
- Removed powerpc-Enable-interrupts-in-do_signal.patch
- Removed powerpc-Disable-sparse-irq-for-RT.patch
- Removed lockdep-Reduce-stack_trace-usage.patch
- Removed bz579408-hvc_console-Fix-race-between-hvc_close-and-hvc_remov.patch
- Removed timer_stats-Convert-table_lock-to-raw_spin_lock.patch
- Removed bz568621-hvc_console-Fix-race-between_close_and_remov.patch
- Removed bz585096-KEYS-find_keyring_by_name-can-gain-access-to-a-freed.patch
- Removed perf_events-fix-errors-path-in-perf_output_begin.patch
- Removed trace-Update-the-comm-field-in-the-right-variable-i.patch

* Tue Jul 13 2010 John Kacur <jkacur@redhat.com> - 2.6.33.5-rt23-mrg27
- Added the bnx2-backport.patch
- Added bnx2x-FW-5.2.13.patch

* Mon Jul 12 2010 John Kacur <jkacur@redhat.com> - 2.6.33.5-rt23-mrg26
- Added no-vfs.patch to revert the dcache problems

* Fri Jul 2 2010 John Kacur <jkacur@redhat.com> - 2.6.33.5-rt23-mrg25
- Added gianfar-Fix-TX-ring-processing-on-SMP-machines.patch
- Renabled bz465837-rtc-compat-rhel5.patch-ported-to-V2.patch

* Wed Jun 30 2010 John Kacur <jkacur@redhat.com> - 2.6.33.5-rt23-mrg24
- The following two patches address the dcache problem
- Added Revert_select_parent_locking_fix.patch
- Added Make_sure_d_kill_sets_d_parent_to_null.patch

* Wed Jun 16 2010 John Kacur <jkacur@redhat.com> - 2.6.33.5-rt23-mrg23
- Added powerpc-Enable-interrupts-in-do_signal.patch
- Added powerpc-Disable-sparse-irq-for-RT.patch
- Added lockdep-Reduce-stack_trace-usage.patch
- Disabled lockdep-Make-MAX_STACK_TRACE_ENTRIES-configurable.patch
- commented out CONFIG_MAX_STACK_TRACE_ENTRIES=393216 in config-debug
- Added bz579408-hvc_console-Fix-race-between-hvc_close-and-hvc_remov.patch
- Added timer_stats-Convert-table_lock-to-raw_spin_lock.patch
- CONFIG_SCSI_MPT2SAS=m added to config-generic
- CONFIG_XFS_FS=m added to config-generic
- CONFIG_XFS_POSIX_ACL=y added to config-generic

* Thu Jun 10 2010 John Kacur <jkacur@redhat.com> - 2.6.33.5-rt23-mrg22
- Rebasing to 2.6.33.5-rt23

* Mon Jun 7 2010 John Kacur <jkacur@redhat.com> - 2.6.33.5-rt22-mrg21
- Replaced nfs4-Prevent-deadlock.patch with Avoid_NFS_igrab_deadlock.patch
- Added Fix_d_genocide-from_decrementing_d_count_more_than_once.patch
- Added Fix_select_parent_dentry_traversal_locking.patch

* Tue Jun 1 2010 John Kacur <jkacur@redhat.com> - 2.6.33.5-rt22-mrg20
- Rebasing to 2.6.33.5-rt22
- Removed net-ehea-make-rx-irq-handler-non-threaded-IRQF_NODEL.patch
- Removed fs-namespace-Fix-fuse-mount-fallout.patch

* Wed May 26 2010 John Kacur <jkacur@redhat.com> - 2.6.33.4-rt20-mrg19
- For the following four i7core_edac patches, see bz582574
- Added i7core_edac-Bring-the-i7core_edac-up-to-date-with-li.patch
- Added i7core_edac-Always-call-i7core_-ur-dimm_check_mc_ecc.patch
- Added i7core_edac-i7core_register_mci-should-not-fall-thro.patch
- Added i7core_edac-Add-support-for-Westmere-to-i7core_edac.patch
- Added nfs4-Prevent-deadlock.patch - see bz596111

* Thu May 20 2010 John Kacur <jkacur@redhat.com> - 2.6.33.4-rt20-mrg18
- Added bz585096-KEYS-find_keyring_by_name-can-gain-access-to-a-freed.patch
- Added net-ehea-make-rx-irq-handler-non-threaded-IRQF_NODEL.patch
- Added fs-namespace-Fix-fuse-mount-fallout.patch

* Tue May 18 2010 John Kacur <jkacur@redhat.com> - 2.6.33.4-rt20-mrg17
- Rebasing to 2.6.33.4-rt20
- Removed fs-Add-missing-parantheses.patch
- Removed autofs-deadlock-fixes.patch
- Removed fs-Fix-mnt_count-typo.patch
- Removed fs-Resolve-mntput_no_expire-issues.patch
- Added perf_events-fix-errors-path-in-perf_output_begin.patch

* Fri May 14 2010 John Kacur <jkacur@redhat.com> - 2.6.33.3-rt19-mrg16
- Added fs-Fix-mnt_count-typo.patch
- Added fs-Resolve-mntput_no_expire-issues.patch

* Tue May 11 2010 John Kacur <jkacur@redhat.com> - 2.6.33.3-rt19-mrg15
- Two fixes from John Stultz for autofs deadlocks

* Thu May 6 2010 John Kacur <jkacur@redhat.com> - 2.6.33.3-rt19-mrg14
- Rebased to 2.6.33.3-rt19
- Started clean-up of the spec file

* Fri Apr 16 2010 John Kacur <jkacur@redhat.com> - 2.6.33.2-rt13-mrg13
- Added tracing-x86-Add-check-to-detect-GCC-messing-with-mco.patch
-	Fixes the problem where the function_graph is not available on 32-bit
- Added lockdep-Make-MAX_STACK_TRACE_ENTRIES-configurable.patch
- Made the default MAX_STACK_TRACE_ENTRIES to 393216 for config-debug

* Fri Apr 9 2010 John Kacur <jkacur@redhat.com> - 2.6.33.2-rt13-mrg12
- Added bz568621-hvc_console-Fix-race-between_close_and_remov.patch

* Wed Apr 7 2010 John Kacur <jkacur@redhat.com> - 2.6.33.2-rt13-mrg11
- Rebased to 2.6.33.2-rt13

* Tue Mar 30 2010 John Kacur <jkacur@redhat.com> - 2.6.33.1-rt11-mrg10
- Added Fix-CONFIG_STACK_TRACER-warning.patch 
- Turned CONFIG_STACK_TRACER back on in the production build
- Added x86-32-clean-up-rwsem-inline-asm-statements.patch
- Added x86-clean-up-rwsem-type-system.patch
- Added x86-64-rwsem-64-bit-xadd-rwsem-implementation.patch
- Added x86-Fix-breakage-of-UML-from-the-changes-in-the-rwse.patch
- Added x86-64-support-native-xadd-rwsem-implementation.patch
- Added x86-64-rwsem-Avoid-store-forwarding-hazard-in-__down.patch
- Added sched-sched_getaffinity-Allow-less-than-NR_CPUS-leng.patch

* Mon Mar 22 2010 John Kacur <jkacur@redhat.com> 2.6.33.1-rt11-mrg9
- rebasing to 2.6.33.1-rt11
- Changing the production config to CONFIG_STACK_TRACER is not set

* Thu Mar 18 2010 John Kacur <jkacur@redhat.com> 2.6.33.1-rt10-mrg8
- rebasing to 2.6.33.1-rt10

* Wed Mar 17 2010 John Kacur <jkacur@redhat.com> - 2.6.33.1-rt9-mrg8
- Rebasing to 2.6.33.1-rt9
- disable the lockbreak-in-load-balancer-for-RT.patch as it is already there

* Tue Mar 16 2010 John Kacur <jkacur@redhat.com> - 2.6.33.1-rt7-mrg7
- Reenabling the IBM patches for raw memory eg:
	- Add-dev-rmem-device-driver-for-real-time-JVM-testing.patch
	- ibm-rmem-for-rtsj.patch
- Added stable patch 2.6.33.1
- added CONFIG_FTRACE=y to config-generic

* Tue Mar 16 2010 John Kacur <jkacur@redhat.com> - 2.6.33-rt7-mrg6
- Added the 0001-lockbreak-in-load-balancer-for-RT.patch

* Fri Mar 12 2010 John Kacur <jkacur@redhat.com> - 2.6.33-rt7-mrg5
- rebased to 2.6.33-rt7
- Due to the rebase, we can drop mm-highmem.c-Fix-pkmap_count-undeclared.patch

* Tue Mar 9 2010 John Kacur <jkacur@redhat.com> - 2.6.33-rt4-mrg4
- disabled forward-port-of-limit-i386-ram-to-16gb.patch
-     the only part of the above patch left was rejected as unnecessary on lkml
- Added trace-Update-the-comm-field-in-the-right-variable-i.patch

* Wed Mar 3 2010 John Kacur <jkacur@redhat.com> - 2.6.33-rt4-mrg3
- Rebased to 2.6.33-rt4
- Added mm-highmem.c-Fix-pkmap_count-undeclared.patch

* Thu Feb 25 2010 John Kacur <jkacur@redhat.com> - 2.6.33-rc8-rt2-mrg2
- Rebased to 2.6.33-rc8-rt2
- Fixed config options, where options are no longer available as modules

* Wed Feb 24 2010 John Kacur <jkacur@redhat.com> - 2.6.33-rc8-rt1-mrg1
- Respinning to 2.6.33-rc8-rt1-mrg1
- Removed many patches, most because they are already in 2.6.33-rc8,
	- some because they need review, and may no-longer apply.

